@@ -544,12 +544,12 @@ class StorageController(Protocol):
 # logger
 @runtime_checkable
 class PluginLogger(Protocol):
-    def log(self, *args: Union[str, dict, Exception]) -> None: ...
-    def error(self, *args: Union[str, dict, Exception]) -> None: ...
-    def warn(self, *args: Union[str, dict, Exception]) -> None: ...
-    def attention(self, *args: Union[str, dict, Exception]) -> None: ...
-    def debug(self, *args: Union[str, dict, Exception]) -> None: ...
-    def trace(self, *args: Union[str, dict, Exception]) -> None: ...
+    def log(self, *args: Union[str, Dict, Exception]) -> None: ...
+    def error(self, *args: Union[str, Dict, Exception]) -> None: ...
+    def warn(self, *args: Union[str, Dict, Exception]) -> None: ...
+    def attention(self, *args: Union[str, Dict, Exception]) -> None: ...
+    def debug(self, *args: Union[str, Dict, Exception]) -> None: ...
+    def trace(self, *args: Union[str, Dict, Exception]) -> None: ...
 
 
 # config service
@@ -847,7 +847,7 @@ class PluginAPI(Protocol):
 # base plugin
 class BasePlugin(ABC):
     @abstractmethod
-    async def on_form_submit(self, action_id: str, payload: Any) -> Optional[dict]:
+    async def on_form_submit(self, action_id: str, payload: Any) -> Optional[Dict]:
         pass
 
     @abstractmethod
